@@ -1,5 +1,5 @@
 # ANALYSIS Utilities/"Generate phenodata" (If run on a prenormalized file, generates a blank phenodata for it.)
-# INPUT GENE_EXPRS normalized.tsv OUTPUT phenodata.tsv
+# INPUT GENE_EXPRS normalized.tsv OUTPUT phenodata.tsv, normalized.tsv
 # PARAMETER chiptype STRING DEFAULT empty (Chiptype)
 
 
@@ -24,5 +24,6 @@ if(chiptype=="empty") {
    chiptype<-chiptype
 }
 
-# Writes out the phenodata table
+# Writes out the data and the phenodata table
+write.table(dat, file="normalized.tsv", sep="\t", row.names=T, col.names=T, quote=F)
 write.table(data.frame(sample=sample, chiptype=chiptype, group=group, training=training), file="phenodata.tsv", sep="\t", row.names=F, col.names=T, quote=F)
