@@ -1,11 +1,11 @@
 # ANALYSIS Normalisation/"Agilent 1-color" (Agilent one-color data preprocessing. Automatically averages all the rows,
 # i.e., genes that have the same name. YOU HAVE TO SPECIFY THE CHIPTYPE.)
 # INPUT CDNA microarray[...].tsv OUTPUT normalized.tsv, phenodata.tsv
-# PARAMETER background.treatment [none, subtract, edwards, normexp] DEFAULT subtract (Background treatment method)
-# PARAMETER background.offset [0, 50] DEFAULT 0 (Background offset)
+# PARAMETER background.treatment [none, subtract, edwards, normexp] DEFAULT normexp (Background treatment method)
+# PARAMETER background.offset [0, 50] DEFAULT 50 (Background offset)
 # PARAMETER normalize.genes [none, scale, quantile, vsn] DEFAULT none (Between arrays normalization method)
 # PARAMETER remove.control.probes [yes, no] DEFAULT no (Remove control probes from the dataset)
-# PARAMETER chiptype [empty, Human-1 (4100a), Human-2 (4101a), Human-1A (4110b), Human-1B (4111a), Human-Whole-Genome (4112a), Mouse (4104a), Mouse (4120a), Mouse (4121a), Mouse (4122a), Rat (4105a), Rat (4130a), zebrafish, drosophila] DEFAULT empty (chiptype)
+# PARAMETER chiptype [empty, Human-1 (4100a), Human-2 (4101a), Human-1A (4110b), Human-1B (4111a), Human-Whole-Genome (4112a), Mouse (4104a), Mouse (4120a), Mouse (4121a), Mouse (4122a), Rat (4105a), Rat (4130a), Rat (4131), zebrafish, drosophila] DEFAULT empty (chiptype)
 
 
 # cDNA chip normalization
@@ -76,12 +76,18 @@ if(chiptype=="Rat(4105a)") {
 if(chiptype=="Rat(4130a)") {
    chiptype<-c("rgug4130a")
 }
+if(chiptype=="Rat(4131)") {
+   chiptype<-c("rgug4131unigene")
+}
 if(chiptype=="zebrafish") {
    chiptype<-c("AgilentZF")
 }
 if(chiptype=="drosophila") {
    chiptype<-c("DrosoAgilent")
 }
+if(chiptype=="rhesus") {
+   chiptype<-c("rhesusrefseq")
+}
 write.table(data.frame(sample=sample, chiptype=chiptype, group=group, training=training), file="phenodata.tsv", sep="\t", row.names=F, col.names=T, quote=F)
 
 # Removes control probes
@@ -109,9 +115,26 @@ names(M)<-paste("chip.", names(M), sep="")
 M<-data.frame(M)
 rownames(M)<-genes
 
-# Conditional on whether flags are included or not, write the data to disk
-if(nrow(flags)!=nrow(M)) {
-   write.table(data.frame(round(M, digits=2)), file="normalized.tsv", col.names=T, quote=F, sep="\t", row.names=T)
-} else {
-   write.table(data.frame(round(M, digits=2), flags), file="normalized.tsv", col.names=T, quote=F, sep="\t", row.names=T)
+if(chiptype!="cDNA") {
+   # Including gene names to data
+   library(chiptype, character.only=T)
+   symbol<-gsub("\'", "", data.frame(unlist(as.list(get(paste(chiptype, "SYMBOL", sep="")))))[rownames(M),])
+   genename<-gsub("\'", "", data.frame(unlist(as.list(get(paste(chiptype, "GENENAME", sep="")))))[rownames(M),])
+}
+
+if(chiptype!="cDNA") {
+   # Conditional on whether flags are included or not, write the data to disk
+   if(nrow(flags)!=nrow(M)) {
+      write.table(data.frame(symbol, description=genename, round(M, digits=2)), file="normalized.tsv", col.names=T, quote=F, sep="\t", row.names=T)
+   } else {
+     write.table(data.frame(symbol, description=genename, round(M, digits=2), flags), file="normalized.tsv", col.names=T, quote=F, sep="\t", row.names=T)
+   }
+}
+
+if(chiptype=="cDNA") {
+   if(nrow(flags)!=nrow(M)) {
+      write.table(data.frame(round(M, digits=2)), file="normalized.tsv", col.names=T, quote=F, sep="\t", row.names=T)
+   } else {
+     write.table(data.frame(round(M, digits=2), flags), file="normalized.tsv", col.names=T, quote=F, sep="\t", row.names=T)
+   }
 }
