@@ -410,29 +410,57 @@ if(column1!="EMPTY" & column2!="EMPTY" & column3!="EMPTY" & column4!="EMPTY" & c
 
 
 # Extracting the significant results
-m<-matrix(nrow=nrow(dat2), ncol=ncol(design)-1)
-mm<-matrix(nrow=nrow(dat2), ncol=ncol(design)-1)
-for(i in 2:ncol(design)) {
-   pp<-toptable(fit, coef=i, number=nrow(dat2), adjust.method=adj.method)
-   ppind<-as.numeric(rownames(pp))
-   ppind<-order(ppind)
+# m<-matrix(nrow=nrow(dat2), ncol=ncol(design)-1)
+# mm<-matrix(nrow=nrow(dat2), ncol=ncol(design)-1)
+# for(i in 2:ncol(design)) {
+#   pp<-toptable(fit, coef=i, number=nrow(dat2), adjust.method=p.value.adjustment.method)
+#   ppind<-as.numeric(rownames(pp))
+#   ppind<-order(ppind)
+#   if(adjust.p.values=="yes") {
+#      pp2<-pp$adj.P.Val[ppind]
+#   }
+#   if(adjust.p.values=="no") {
+#      pp2<-pp$P.Value[ppind]
+#   }
+#   m[,(i-1)]<-pp2
+#   pp3<-pp$logFC[ppind]
+#   mm[,(i-1)]<-pp3
+#}
+#
+# Writing the data to disk
+#m<-data.frame(m)
+#mm<-data.frame(mm)
+#colnames(m)<-paste("p.adjusted.", colnames(design)[-1], sep="")
+#colnames(mm)<-paste("FC.", colnames(design)[-1], sep="")
+#dat3<-data.frame(dat2, round(m, digits=4), round(mm, digits=2))
+#write.table(dat3, file="limma.tsv", sep="\t", row.names=T, col.names=T, quote=F)
+#write.table(design, file="limma-design.tsv", sep="\t", row.names=F, col.names=T, quote=F)
+
+
+## New method ##
+m<-matrix(nrow=nrow(dat2), ncol=ncol(design))
+mm<-matrix(nrow=nrow(dat2), ncol=ncol(design))
+for(i in 1:ncol(design)) {
+   pp<-toptable(fit, coef=i, number=nrow(dat2), adjust.method=p.value.adjustment.method, sort.by="p")
+   rownames(pp)<-rownames(dat2[as.numeric(rownames(pp)),])
    if(adjust.p.values=="yes") {
-      pp2<-pp$adj.P.Val[ppind]
+      pp2<-pp$adj.P.Val
    }
    if(adjust.p.values=="no") {
-      pp2<-pp$P.Value[ppind]
+      pp2<-pp$P.Value
    }
-   m[,(i-1)]<-pp2
-   pp3<-pp$logFC[ppind]
-   mm[,(i-1)]<-pp3
+   pp3<-pp$logFC
+   pp2<-pp2[order(rownames(pp))]
+   pp3<-pp3[order(rownames(pp))]
+   m[,(i)]<-pp2
+   mm[,(i)]<-pp3
 }
 
-
 # Writing the data to disk
 m<-data.frame(m)
 mm<-data.frame(mm)
-colnames(m)<-paste("p.adjusted.", colnames(design)[-1], sep="")
-colnames(mm)<-paste("FoldChange.", colnames(design)[-1], sep="")
-dat3<-data.frame(dat2, round(m, digits=4), round(mm, digits=2))
+colnames(m)<-paste("p.adjusted.", colnames(design), sep="")
+colnames(mm)<-paste("FC.", colnames(design), sep="")
+dat3<-data.frame(dat, round(m, digits=4), round(mm, digits=2))
 write.table(dat3, file="limma.tsv", sep="\t", row.names=T, col.names=T, quote=F)
 write.table(design, file="limma-design.tsv", sep="\t", row.names=F, col.names=T, quote=F)
